'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _mkdirp = require('mkdirp');

var _mkdirp2 = _interopRequireDefault(_mkdirp);

var _os = require('os');

var _os2 = _interopRequireDefault(_os);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _request = require('request');

var _request2 = _interopRequireDefault(_request);

var _semver = require('semver');

var _semver2 = _interopRequireDefault(_semver);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var downloadFFMPEG = function downloadFFMPEG(electronVersion, platform, arch) {
  return new Promise(function (resolve, reject) {
    if (!_semver2.default.satisfies(electronVersion, '>=0.36.8')) return reject(new Error('Electron version too low'));
    if (!process.env.TESTING) console.log('Downloading patent safe FFMPEG for platform ' + platform + ' ' + arch + ' using electron v' + electronVersion);

    var tmpPath = _path2.default.resolve(_os2.default.tmpdir(), 'tmp-safe-ffmpeg');
    (0, _mkdirp2.default)(tmpPath, function (err) {
      if (err) return reject(err);

      var ffmpegFileName = 'ffmpeg-v' + electronVersion + '-' + platform + '-' + arch + '.zip';
      var downloadPath = _path2.default.resolve(tmpPath, ffmpegFileName);

      if (_fs2.default.existsSync(downloadPath)) return resolve(downloadPath);

      var downloadStream = _fs2.default.createWriteStream(downloadPath);
      (0, _request2.default)({
        url: 'https://github.com/electron/electron/releases/download/v' + electronVersion + '/' + ffmpegFileName,
        followAllRedirects: true,
        timeout: 10000,
        gzip: true
      }).on('error', function (downloadError) {
        reject(downloadError);
      }).pipe(downloadStream).on('close', function () {
        resolve(downloadPath);
      });
    });
  });
};

exports.default = downloadFFMPEG;